Crate wreq_proto

Crate wreq_proto 

wreq-proto

wreq HTTP client protocol and utilities.

Much of this codebase is adapted and refined from hyper, aiming to match its performance and reliability for asynchronous HTTP/1 and HTTP/2.

Modules

body
Streaming bodies for Requests and Responses
conn
Lower-level client connection API.
ext
Extensions for HTTP messages in wreq_proto.
http1
HTTP/1 protocol implementation and utilities.
http2
HTTP/2 protocol implementation and utilities.
rt
Runtime components
upgrade
HTTP Upgrades

Structs

Error
Represents errors that can occur handling HTTP streams.

Type Aliases

Result
Result type often returned from methods that can have crate::core: Errors.