pub struct Builder<Ex> { /* private fields */ }Expand description
A builder to configure an HTTP connection.
After setting options, the builder is used to create a handshake future.
Note: The default values of options are not considered stable. They are subject to change at any time.
Implementations
Sourceimpl<Ex> Builder<Ex>where
Ex: Clone,
impl<Ex> Builder<Ex>where
Ex: Clone,
Sourcepub fn options(self, opts: Http2Options) -> Self
pub fn options(self, opts: Http2Options) -> Self
Provide a options configuration for the HTTP/2 connection.
Sourcepub async fn handshake<T, B>(
self,
io: T,
) -> Result<(SendRequest<B>, Connection<T, B, Ex>)>
pub async fn handshake<T, B>( self, io: T, ) -> Result<(SendRequest<B>, Connection<T, B, Ex>)>
Constructs a connection with the configured options and IO.
Note, if Connection is not await-ed, SendRequest will
do nothing.