Module http2

Module http2 

HTTP/2 protocol implementation and utilities.

Structs

Http2Options
Options for tuning HTTP/2 connections.
Http2OptionsBuilder
Builder for Http2Options.
Priorities
A collection of HTTP/2 PRIORITY frames.
PrioritiesBuilder
A builder for constructing a Priorities collection.
Priority
The PRIORITY frame (type=0x2) specifies the sender-advised priority of a stream [Section 5.3]. It can be sent in any stream state, including idle or closed streams. [Section 5.3]: https://tools.ietf.org/html/rfc7540#section-5.3
PseudoOrder
Represents the order of HTTP/2 pseudo-header fields in a header block.
Setting
A struct representing a single HTTP/2 setting that can be sent in a SETTINGS frame.
SettingsOrder
Represents the order of settings in a SETTINGS frame.
SettingsOrderBuilder
A builder for constructing a SettingsOrder.
StreamDependency
Represents a stream dependency in HTTP/2 priority frames.
StreamId
A stream identifier, as described in Section 5.1.1 of RFC 7540.

Enums

PseudoId
Represents the order of HTTP/2 pseudo-header fields in the header block.
SettingId
An enum that lists all valid settings that can be sent in a SETTINGS frame.