#[repr(u8)]pub enum PseudoId {
Method = 1,
Scheme = 2,
Authority = 3,
Path = 4,
Protocol = 5,
Status = 6,
}Expand description
Represents the order of HTTP/2 pseudo-header fields in the header block.
HTTP/2 pseudo-header fields are a set of predefined header fields that start with ‘:’. The order of these fields in a header block is significant. This enum defines the possible pseudo-header fields and their standard order according to RFC 7540.
Variants