#[repr(u16)]pub enum SettingId {
HeaderTableSize = 1,
EnablePush = 2,
MaxConcurrentStreams = 3,
InitialWindowSize = 4,
MaxFrameSize = 5,
MaxHeaderListSize = 6,
EnableConnectProtocol = 8,
NoRfc7540Priorities = 9,
Unknown(u16),
}Expand description
An enum that lists all valid settings that can be sent in a SETTINGS frame.
Each setting has a value that is a 32 bit unsigned integer (6.5.1.).
See https://datatracker.ietf.org/doc/html/rfc9113#name-defined-settings.
Variants
HeaderTableSize = 1
This setting allows the sender to inform the remote endpoint of the maximum size of the compression table used to decode field blocks, in units of octets. The encoder can select any size equal to or less than this value by using signaling specific to the compression format inside a field block (see COMPRESSION). The initial value is 4,096 octets.
EnablePush = 2
Enables or disables server push.
MaxConcurrentStreams = 3
Specifies the maximum number of concurrent streams.
InitialWindowSize = 4
Sets the initial stream-level flow control window size.
MaxFrameSize = 5
Indicates the largest acceptable frame payload size.
MaxHeaderListSize = 6
Advises the peer of the max field section size.
EnableConnectProtocol = 8
Enables support for the Extended CONNECT protocol.
NoRfc7540Priorities = 9
Disable RFC 7540 Stream Priorities. [RFC 9218]: https://www.rfc-editor.org/rfc/rfc9218.html#section-2.1
Unknown(u16)