Setting

Struct Setting 

pub struct Setting { /* private fields */ }
A struct representing a single HTTP/2 setting that can be sent in a SETTINGS frame.

Each setting consists of an identifier and a value, where the value is a 32-bit unsigned integer (see RFC 7540, section 6.5.1).

Implementations

Source

impl Setting

pub fn from_id(id: impl Into<SettingId>, value: u32) -> Option<Setting>

Creates a new Setting with the correct variant corresponding to the given setting id, based on the settings IDs defined in section 6.5.2.